// TEST CASE FOR WRITING TO PRE-EXISTING DATABASES
// To use:
// 1: Compile
// 2: Run "driver.exe 1" to persist John
// 3: Run "driver.exe 2" to persist Jane
// 4: Open the sql file and see if both Jane and Jane are in the person table
// 5: Optional: Switch the create_database method that is commented out in the code

#include <memory>   // std::auto_ptr
#include <iostream>

#include <odb/database.hxx>
#include <odb/transaction.hxx>

#include "database.hxx" // create_database

#include "person.hxx"
#include "person-odb.hxx"

using namespace std;
using namespace odb::core;

int
main (int argc, char* argv[])
{
	unsigned long john_id, jane_id;
	try
	{
		int persistElement = -1;

		// Attempt 1
		int nargs = 4;
		char* dbStr[] = {"NULL", "--create", "--database", "xyz.sql"};
		auto_ptr<database> db (create_database(nargs, dbStr));

		// Attempt 2
		//int nargs = 3;
		//char* dbStr[] = {"NULL", "--database", "xyz.sql"};
		//auto_ptr<database> db (create_database(nargs, dbStr));

		// Create a persistent person object.
		//
		if (argc == 2) {
			persistElement = atoi(argv[1]);
			transaction t (db->begin ());
			if (persistElement == 1) {
				printf("Persisting John ...\n");
				person john ("John", "Doe", 33);
				john_id = db->persist (john);
			}
			else if (persistElement == 2) {
				printf("Persisting Jane ...\n");
				person jane ("Jane", "Doe", 32);
				jane_id = db->persist (jane);
			}
			else {
				printf("Invalid option. Input argument must be 1 or 2\n");
			}
			t.commit ();		
		}
		else {
			printf("No argument provided. Input argument must be 1 or 2\n");
		}
	}
	catch (const odb::exception& e)	{
		cerr << e.what () << endl;
		return 1;
	}
	return 0;
}
